@@ -22,7 +22,7 @@ class Result(object):
 		The method to get the page
 
 		Returns:
-			int: A int value
+			int: An int representing the page
 		"""
 
 		return self.__page
@@ -46,7 +46,7 @@ class Result(object):
 		The method to get the count
 
 		Returns:
-			int: A int value
+			int: An int representing the count
 		"""
 
 		return self.__count
@@ -70,7 +70,7 @@ class Result(object):
 		The method to get the download_url
 
 		Returns:
-			string: A string value
+			string: A string representing the download_url
 		"""
 
 		return self.__download_url
@@ -94,7 +94,7 @@ class Result(object):
 		The method to get the per_page
 
 		Returns:
-			int: A int value
+			int: An int representing the per_page
 		"""
 
 		return self.__per_page
@@ -118,7 +118,7 @@ class Result(object):
 		The method to get the more_records
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the more_records
 		"""
 
 		return self.__more_records
@@ -145,7 +145,7 @@ class Result(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
