@@ -28,10 +28,10 @@ class ContactRolesOperations(object):
 
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Contacts/roles'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
+		api_path = api_path + '/crm/v2.1/Contacts/roles'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.response_handler import ResponseHandler
 		except Exception:
@@ -62,13 +62,13 @@ class ContactRolesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Contacts/roles'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_POST
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_CREATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		api_path = api_path + '/crm/v2.1/Contacts/roles'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
 		except Exception:
@@ -99,20 +99,20 @@ class ContactRolesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Contacts/roles'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
-		handler_instance.mandatory_checker = True
+		api_path = api_path + '/crm/v2.1/Contacts/roles'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
 		except Exception:
 			from .action_handler import ActionHandler
 		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
 
-	def delete_contact_roles(self, param_instance):
+	def delete_contact_roles(self, param_instance=None):
 		"""
 		The method to delete contact roles
 
@@ -131,11 +131,11 @@ class ContactRolesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Contacts/roles'
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.param = param_instance
+		api_path = api_path + '/crm/v2.1/Contacts/roles'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_param(param_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
 		except Exception:
@@ -161,24 +161,24 @@ class ContactRolesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Contacts/roles/'
+		api_path = api_path + '/crm/v2.1/Contacts/roles/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_GET
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_READ
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.response_handler import ResponseHandler
 		except Exception:
 			from .response_handler import ResponseHandler
 		return handler_instance.api_call(ResponseHandler.__module__, 'application/json')
 
-	def update_contact_role(self, request, id):
+	def update_contact_role(self, id, request):
 		"""
 		The method to update contact role
 
 		Parameters:
-			request (BodyWrapper) : An instance of BodyWrapper
 			id (int) : An int representing the id
+			request (BodyWrapper) : An instance of BodyWrapper
 
 		Returns:
 			APIResponse: An instance of APIResponse
@@ -192,21 +192,21 @@ class ContactRolesOperations(object):
 		except Exception:
 			from .body_wrapper import BodyWrapper
 
-		if request is not None and not isinstance(request, BodyWrapper):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
-		
 		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Contacts/roles/'
+		api_path = api_path + '/crm/v2.1/Contacts/roles/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_PUT
-		handler_instance.category_method = Constants.REQUEST_CATEGORY_UPDATE
-		handler_instance.content_type = 'application/json'
-		handler_instance.request = request
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
 		except Exception:
@@ -232,11 +232,11 @@ class ContactRolesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Contacts/roles/'
+		api_path = api_path + '/crm/v2.1/Contacts/roles/'
 		api_path = api_path + str(id)
-		handler_instance.api_path = api_path
-		handler_instance.http_method = Constants.REQUEST_METHOD_DELETE
-		handler_instance.category_method = Constants.REQUEST_METHOD_DELETE
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
+		handler_instance.set_category_method(Constants.REQUEST_METHOD_DELETE)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.contact_roles.action_handler import ActionHandler
 		except Exception:
