@@ -1,5 +1,6 @@
 from .private import Private
 from .related_details import RelatedDetails
+from .multi_user_lookup import MultiUserLookup
 from .crypt import Crypt
 from .module import Module
 from .view_type import ViewType
@@ -8,10 +9,12 @@ from .fields_operations import FieldsOperations, GetFieldsParam, GetFieldParam
 from .multi_select_lookup import MultiSelectLookup
 from .tool_tip import ToolTip
 from .api_exception import APIException
+from .external import External
 from .response_handler import ResponseHandler
 from .field import Field
 from .association_details import AssociationDetails
 from .unique import Unique
+from .history_tracking import HistoryTracking
 from .response_wrapper import ResponseWrapper
 from .formula import Formula
 from .currency import Currency
