@@ -38,7 +38,7 @@ class ProfilesOperations(object):
 
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/profiles'
+		api_path = api_path + '/crm/v2.1/settings/profiles'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
@@ -68,7 +68,7 @@ class ProfilesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/profiles/'
+		api_path = api_path + '/crm/v2.1/settings/profiles/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
