@@ -18,7 +18,7 @@ class ConflictWrapper(object):
 		The method to get the conflict_id
 
 		Returns:
-			string: A string value
+			string: A string representing the conflict_id
 		"""
 
 		return self.__conflict_id
@@ -45,7 +45,7 @@ class ConflictWrapper(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
