@@ -57,7 +57,7 @@ class Utility(object):
                 split_lower = api_path_split[i].lower()
                 if split_lower == module_api_name.lower():
                     api_path_split[i] = module_api_name
-                elif split_lower in Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower) and Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower) is not None:
+                elif split_lower in Constants.DEFAULT_MODULENAME_VS_APINAME and Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower) is not None:
                     api_path_split[i] = Constants.DEFAULT_MODULENAME_VS_APINAME.get(split_lower)
 
             api_path = "/".join(api_path_split)
